==> fr.ac6.linux.utils_1.0.0.202110251403.jar: resources/scripts/distutils_utils.sh <==
# 
# Distutils class functions
#

require_script python_utils.sh

default_value_if_not_set \
	distutils_build_other_flags \
	$make_other_flags
	
default_value_if_not_set \
	distutils_install_other_flags \
	$make_install_other_flags

distutils_do_configure() {
	if [ "${CLEANBROKEN}" != "1" ] ; then
		export NO_FETCH_BUILD=1
		log_exec $NATIVE_SYSROOT_LOC/usr/bin/python setup.py \
		         clean \
		         $distutils_build_other_flags
	fi
}

distutils_do_compile() {
##	export LDSHARED="$CCLD -shared"
	export STAGING_INCDIR=$includedir
	export STAGING_LIBDIR=$libdir
##	export NO_FETCH_BUILD=1
#	export PYTHONHOME=${NATIVE_SYSROOT_LOC}/usr/
#	export PYTHONPATH=${PYTHON_SITEPACKAGES_DIR}:$libdir/${PYTHON_DIR}:$libdir/${PYTHON_DIR}/lib-dynload
	log_exec $NATIVE_SYSROOT_LOC/usr/bin/python setup.py \
	         build \
	         $distutils_build_other_flags
}

distutils_do_install() {
	log_exec install -d ${installDir}${PYTHON_SITEPACKAGES_DIR}
##	export LDSHARED="$CCLD -shared"
	export STAGING_INCDIR=${includedir}
	export STAGING_LIBDIR=${libdir}
##	export NO_FETCH_BUILD=1
#	export PYTHONHOME=${NATIVE_SYSROOT_LOC}/usr/
#	export PYTHONPATH=${PYTHON_SITEPACKAGES_DIR}
	log_exec $NATIVE_SYSROOT_LOC/usr/bin/python setup.py install \
				--root=$installDir \
				--prefix=$prefix \
				--exec-prefix=$exec_prefix \
				--install-lib=${PYTHON_SITEPACKAGES_DIR} \
				$distutils_install_other_flags
	
	# support filenames with *spaces*
	# only modify file if it contains path  and recompile it
	find ${installDir} -name "*.py" -exec grep -q ${installDir} {} \; -exec sed -i -e s:${installDir}::g {} \; -exec $bindir/python -mcompileall {} \;
	
	if [ -e ${installDir}${bindir} ]; then
		for i in ${installDir}${bindir}/* ; do \
			if $recipe_is_native || $recipe_is_cross; then
				true # Nothing to do
			else
				sed -i -e s:${STAGING_BINDIR_NATIVE}/python-native/python:${USRBINPATH}/env\ python:g $i 
			fi 
		    sed -i -e s:${installDir}/${bindir}:${bindir}:g $i
		    sed -i -e s:${installDir}/${sbindir}:${sbindir}:g $i
		done
	fi
	
	if [ -e ${installDir}${sbindir} ]; then
		for i in ${installDir}${sbindir}/* ; do \
			if $recipe_is_native || $recipe_is_cross; then
				true # Nothing to do
			else
				sed -i -e s:$bindir/python:/usr/bin/env\ python:g $i 
			fi 
		    sed -i -e s:${installDir}/${bindir}:${bindir}:g $i
		    sed -i -e s:${installDir}/${sbindir}:${sbindir}:g $i
		done
	fi
	
	rm -f ${installDir}${PYTHON_SITEPACKAGES_DIR}/easy-install.pth
	rm -f ${installDir}${PYTHON_SITEPACKAGES_DIR}/site.py*
	
	#
	# FIXME: Bandaid against wrong datadir computation
	# 
	if [ -e ${installDir}${datadir}/share ]; then
		mv -f ${installDir}${datadir}/share/* ${installDir}${datadir}/
		rmdir ${installDir}${datadir}/share
	fi
	
	# Fix backport modules
	if [ -e ${libdir}/${PYTHON_DIR}/site-packages/backports/__init__.py ] && [ -e ${installDir}${PYTHON_SITEPACKAGES_DIR}/backports/__init__.py ]; then
		rm ${installDir}${PYTHON_SITEPACKAGES_DIR}/backports/__init__.py; 
		rm ${installDir}${PYTHON_SITEPACKAGES_DIR}/backports/__init__.pyc;
	fi
}

==> fr.ac6.linux.utils_1.0.0.202304061034.jar: resources/scripts/distutils_utils.sh <==
# 
# Distutils class functions
#

require_script python_utils.sh

default_value_if_not_set \
	distutils_build_other_flags \
	$make_other_flags
	
default_value_if_not_set \
	distutils_install_other_flags \
	$make_install_other_flags

distutils_do_configure() {
	if [ "${CLEANBROKEN}" != "1" ] ; then
		export NO_FETCH_BUILD=1
		log_exec $NATIVE_SYSROOT_LOC/usr/bin/python setup.py \
		         clean \
		         $distutils_build_other_flags
	fi
}

distutils_do_compile() {
##	export LDSHARED="$CCLD -shared"
	if $recipe_is_cross; then
		export STAGING_INCDIR=${SYSROOT_LOC}${includedir}
		export STAGING_LIBDIR=${SYSROOT_LOC}${libdir}
	elif $recipe_is_native; then
		export STAGING_INCDIR=${includedir}
		export STAGING_LIBDIR=${libdir}
	fi
##	export NO_FETCH_BUILD=1
#	export PYTHONHOME=${NATIVE_SYSROOT_LOC}/usr/
#	export PYTHONPATH=${PYTHON_SITEPACKAGES_DIR}:$libdir/${PYTHON_DIR}:$libdir/${PYTHON_DIR}/lib-dynload
	log_exec $NATIVE_SYSROOT_LOC/usr/bin/python setup.py \
	         build \
	         $distutils_build_other_flags
}

distutils_do_install() {
	log_exec install -d ${installDir}${PYTHON_SITEPACKAGES_DIR}
##	export LDSHARED="$CCLD -shared"
	if $recipe_is_cross; then
		export STAGING_INCDIR=${SYSROOT_LOC}${includedir}
		export STAGING_LIBDIR=${SYSROOT_LOC}${libdir}
	elif $recipe_is_native; then
		export STAGING_INCDIR=${includedir}
		export STAGING_LIBDIR=${libdir}
	fi
##	export NO_FETCH_BUILD=1
#	export PYTHONHOME=${NATIVE_SYSROOT_LOC}/usr/
#	export PYTHONPATH=${PYTHON_SITEPACKAGES_DIR}
	log_exec $NATIVE_SYSROOT_LOC/usr/bin/python setup.py install \
				--root=$installDir \
				--prefix=$prefix \
				--exec-prefix=$exec_prefix \
				--install-lib=${PYTHON_SITEPACKAGES_DIR} \
				$distutils_install_other_flags
	
	# support filenames with *spaces*
	# only modify file if it contains path  and recompile it
	find ${installDir} -name "*.py" -exec grep -q ${installDir} {} \; -exec sed -i -e s:${installDir}::g {} \; -exec $bindir/python -mcompileall {} \;
	
	if [ -e ${installDir}${bindir} ]; then
		for i in ${installDir}${bindir}/* ; do \
			if $recipe_is_native || $recipe_is_cross; then
				true # Nothing to do
			else
				sed -i -e s:${STAGING_BINDIR_NATIVE}/python-native/python:${USRBINPATH}/env\ python:g $i 
			fi 
		    sed -i -e s:${installDir}/${bindir}:${bindir}:g $i
		    sed -i -e s:${installDir}/${sbindir}:${sbindir}:g $i
		done
	fi
	
	if [ -e ${installDir}${sbindir} ]; then
		for i in ${installDir}${sbindir}/* ; do \
			if $recipe_is_native || $recipe_is_cross; then
				true # Nothing to do
			else
				sed -i -e s:$bindir/python:/usr/bin/env\ python:g $i 
			fi 
		    sed -i -e s:${installDir}/${bindir}:${bindir}:g $i
		    sed -i -e s:${installDir}/${sbindir}:${sbindir}:g $i
		done
	fi
	
	rm -f ${installDir}${PYTHON_SITEPACKAGES_DIR}/easy-install.pth
	rm -f ${installDir}${PYTHON_SITEPACKAGES_DIR}/site.py*
	
	#
	# FIXME: Bandaid against wrong datadir computation
	# 
	if [ -e ${installDir}${datadir}/share ]; then
		mv -f ${installDir}${datadir}/share/* ${installDir}${datadir}/
		rmdir ${installDir}${datadir}/share
	fi
	
	# Fix backport modules
	if [ -e ${libdir}/${PYTHON_DIR}/site-packages/backports/__init__.py ] && [ -e ${installDir}${PYTHON_SITEPACKAGES_DIR}/backports/__init__.py ]; then
		rm ${installDir}${PYTHON_SITEPACKAGES_DIR}/backports/__init__.py; 
		rm ${installDir}${PYTHON_SITEPACKAGES_DIR}/backports/__init__.pyc;
	fi
}
